//@line 36 "/export/home/mozilla/uild/firefox1.5.0.1rc1/mozilla/browser/locales/../../browser/locales/en-US/firefox-l10n.js"

//@line 38 "/export/home/mozilla/uild/firefox1.5.0.1rc1/mozilla/browser/locales/../../browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
